==> fine-web-0.0.1-20220919.091035-231.jar: static/js/common/wfCommonphrase.js <==
function initWfCommonphrase(tagargetId){
	if($("#usuallyLang_"+tagargetId).length>0){
		return;
	}
	var str = "<div align='left'><a id=\"usuallyLang_"+tagargetId+"\" href=\"javascript:void(0);\"><span class=\"iconfont icon-comment blue\" style=\"font-size:12px;\">常用语</span></a><div>";
	$.ajax({
		url:ctx+"/WfCommonphrase/findByAccountOrCommon",
		type:"POST",
		async:false,
		success:function(data){
			if(data!=null){
				str+="<div id=\"usuallymenu_"+tagargetId+"\" class=\"easyui-menu\"  style=\"display:none\">\n";
				for(var s=0;s<data.length;s++){
					str+= "<div>"+data[s].commonPhrase+"</div>";
				} 
				str+="<div data-options=\"name:'add',iconCls:'icon-new'\">增加</div></div>";
			}
		},
		error:function(){
			str+="<div id=\"usuallymenu_"+tagargetId+"\" class=\"easyui-menu\"  style=\"display:none\">\n"+
			"<div>同意</div>"+
			"<div>反对</div>"+
			"</div>";
		},
		dataType:"json"
	})
	if($("#usuallyLang_"+tagargetId).length>0){
		return;
	}
	$("#"+tagargetId).before(str);
	$('#usuallymenu_'+tagargetId).menu({ 
		noline:true
	});
		$("#usuallyLang_"+tagargetId).click(function(e){
			console.log($('#usuallymenu_'+tagargetId))
			$('#usuallymenu_'+tagargetId).menu('show', {    
				  left: e.clientX+40,    
				  top: e.clientY ,
				  onClick:function(item){ 
					  if(item.text=='增加'){
						   addCommonphrase(tagargetId);
					   }else{
						   $("#"+tagargetId).textbox("setValue",item.text);
					   }    
				  } 
			});  
		});
		
}
//打开常用语添加弹窗
function addCommonphrase(tagargetId){
	openSaveDialog({
        title: "添加常用语",
        contenturl: '/view/business/edoc/WfCommonphraseform',
        submiturl : '/WfCommonphrase/saveWfCommonphrase',
        width: 330,
        height: 180,
        callback:appendAdd(tagargetId),
    })
}

//给menu添加一个菜单项
function appendAdd(tagargetId){
	return function(result){
		var item = $("#usuallymenu_"+tagargetId).menu('findItem','增加');
		$("#usuallymenu_"+tagargetId).menu('removeItem',item.target);
		$("#usuallymenu_"+tagargetId).menu('appendItem', {
			text: result.o.commonPhrase,
		});
		$("#usuallymenu_"+tagargetId).menu('appendItem', {
			text:'增加',
			iconCls: 'icon-new'
		});
	}
}

==> fine-web-0.0.2-20220909.090829-172.jar: static/js/common/wfCommonphrase.js <==
function initWfCommonphrase(tagargetId){
	if($("#usuallyLang_"+tagargetId).length>0){
		return;
	}
	var str = "<div align='left'><a id=\"usuallyLang_"+tagargetId+"\" href=\"javascript:void(0);\"><span class=\"iconfont icon-comment blue\" style=\"font-size:12px;\">流程常用意见</span></a><div>";
	$.ajax({
		url:ctx+"/WfCommonphrase/findByAccountOrCommon",
		type:"POST",
		async:false,
		success:function(data){
			if(data!=null){
				str+="<div id=\"usuallymenu_"+tagargetId+"\" class=\"easyui-menu\"  style=\"display:none\">\n";
				for(var s=0;s<data.length;s++){
					str+= "<div>"+data[s].commonPhrase+"</div>";
				} 
				str+="<div data-options=\"name:'add',iconCls:'icon-new'\">增加</div></div>";
			}
		},
		error:function(){
			str+="<div id=\"usuallymenu_"+tagargetId+"\" class=\"easyui-menu\"  style=\"display:none\">\n"+
			"<div>同意</div>"+
			"<div>反对</div>"+
			"</div>";
		},
		dataType:"json"
	})
	if($("#usuallyLang_"+tagargetId).length>0){
		return;
	}
	$("#"+tagargetId).before(str);
	$('#usuallymenu_'+tagargetId).menu({ 
		noline:true
	});
		$("#usuallyLang_"+tagargetId).click(function(e){
			console.log($('#usuallymenu_'+tagargetId))
			$('#usuallymenu_'+tagargetId).menu('show', {    
				  left: e.clientX+40,    
				  top: e.clientY ,
				  onClick:function(item){ 
					  if(item.text=='增加'){
						   addCommonphrase(tagargetId);
					   }else{
						   $("#"+tagargetId).textbox("setValue",item.text);
					   }    
				  } 
			});  
		});
		
}
//打开常用语添加弹窗
function addCommonphrase(tagargetId){
	openSaveDialog({
        title: "添加常用语",
        contenturl: '/view/business/edoc/WfCommonphraseform',
        submiturl : '/WfCommonphrase/saveWfCommonphrase',
        width: 330,
        height: 180,
        callback:appendAdd(tagargetId),
    })
}

//给menu添加一个菜单项
function appendAdd(tagargetId){
	return function(result){
		var item = $("#usuallymenu_"+tagargetId).menu('findItem','增加');
		$("#usuallymenu_"+tagargetId).menu('removeItem',item.target);
		$("#usuallymenu_"+tagargetId).menu('appendItem', {
			text: result.o.commonPhrase,
		});
		$("#usuallymenu_"+tagargetId).menu('appendItem', {
			text:'增加',
			iconCls: 'icon-new'
		});
	}
}
